==> qtmobility_1.1.0.orig.tar.gz: qt-mobility-opensource-src-1.1.0/plugins/multimedia/symbian/ecam/s60videorenderercontrol.h <==
/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in 
** accordance with the Qt Commercial License Agreement provided with
** the Software or, alternatively, in accordance with the terms
** contained in a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef S60VIDEORENDERERCONTROL_H
#define S60VIDEORENDERERCONTROL_H

#include <qvideorenderercontrol.h>

/*
 * Control for QGraphicsVideoItem. Viewfinder frames are streamed to a surface
 * which is drawn to the display by the Qt Graphics Vide Framework.
 * VideoRendererControl uses only Bitmap Viewfinder.
 */
class S60VideoRendererControl : public QVideoRendererControl
{
    Q_OBJECT

public: // Constructor & Destructor

    S60VideoRendererControl(QObject *parent = 0);
    virtual ~S60VideoRendererControl();

public: // S60VideoRendererControl

    QAbstractVideoSurface *surface() const;
    void setSurface(QAbstractVideoSurface *surface);

Q_SIGNALS: // Internal Signals

    void viewFinderSurfaceSet();

private: // Data

    QAbstractVideoSurface   *m_surface;

};

#endif // S60VIDEORENDERERCONTROL_H

==> qtmobility_1.2.0.orig.tar.gz: qt-mobility-opensource-src-1.2.0/plugins/multimedia/symbian/ecam/s60videorenderercontrol.h <==
/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:LGPL$
** No Commercial Usage
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the Technology Preview License Agreement accompanying
** this package.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**
**
**
**
**
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef S60VIDEORENDERERCONTROL_H
#define S60VIDEORENDERERCONTROL_H

#include <qvideorenderercontrol.h>

/*
 * Control for QGraphicsVideoItem. Viewfinder frames are streamed to a surface
 * which is drawn to the display by the Qt Graphics Vide Framework.
 * VideoRendererControl uses only Bitmap Viewfinder.
 */
class S60VideoRendererControl : public QVideoRendererControl
{
    Q_OBJECT

public: // Constructor & Destructor

    S60VideoRendererControl(QObject *parent = 0);
    virtual ~S60VideoRendererControl();

public: // S60VideoRendererControl

    QAbstractVideoSurface *surface() const;
    void setSurface(QAbstractVideoSurface *surface);

signals: // Internal Signals

    void viewFinderSurfaceSet();

private: // Data

    QAbstractVideoSurface   *m_surface;

};

#endif // S60VIDEORENDERERCONTROL_H
